from machine import Pin, PWM, time_pulse_us
import time

# Set global variables
max_PWM = 65535
max_distance = 200
speed_of_sound = 29.1 # Speed of sound is ~343 m/s or 29.1 µs per cm

# LED on GPIO 15
led = PWM(Pin(15))
led.freq(1000)

# Ultrasonic sensor setup (HC-SR04)
trig = Pin(28, Pin.OUT)
echo = Pin(27, Pin.IN)

def get_distance():
    # Send a 10µs pulse to TRIG pin
    trig.low()
    time.sleep_us(2)
    trig.high()
    time.sleep_us(10)
    trig.low()

    # Measure the time for the echo to return
    duration = time_pulse_us(echo, 1, 1000000)  # Wait for the echo pin to go high (max 1 second)

    # Convert duration to distance (in cm)
    distance = (duration / 2) / speed_of_sound
    return distance

while True:
    distance = get_distance()
    brightness = int((max_distance-distance) / max_distance * max_PWM)
    brightness = min(max_PWM, max(0, brightness))  # Ensure it stays within bounds
    led.duty_u16(brightness)
    time.sleep(0.1)
